# eric7.Preferences.ConfigurationPages.EditorMouseClickHandlerJediPage

Module implementing the Jedi Mouse Click Handler configuration page.

### Global Attributes

None

### Classes

EditorMouseClickHandlerJediPage | Class implementing the Jedi Mouse Click Handler configuration page.

### Functions

create | Module function to create the configuration page.

## EditorMouseClickHandlerJediPage

Class implementing the Jedi Mouse Click Handler configuration page.

### Derived from

ConfigurationPageBase, Ui_EditorMouseClickHandlerJediPage

### Class Attributes

None

### Class Methods

None

### Methods

EditorMouseClickHandlerJediPage | Constructor
on_changeGotoButton_clicked | Private slot to change the 'goto' mouse click sequence.
save | Public slot to save the Jedi Mouse Click Handler configuration.

### Static Methods

None

#### EditorMouseClickHandlerJediPage (Constructor)

EditorMouseClickHandlerJediPage()

Constructor

#### EditorMouseClickHandlerJediPage.on_changeGotoButton_clicked

on_changeGotoButton_clicked()

Private slot to change the 'goto' mouse click sequence.

#### EditorMouseClickHandlerJediPage.save

save()

Public slot to save the Jedi Mouse Click Handler configuration.

Up

## create

create(dlg)

Module function to create the configuration page.

dlg
  reference to the configuration dialog

Return:
  reference to the instantiated page (ConfigurationPageBase)

Up